# rstr-max

[![PyPI - Version](https://img.shields.io/pypi/v/rstr-max.svg)](https://pypi.org/project/rstr-max)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/rstr-max.svg)](https://pypi.org/project/rstr-max)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install rstr-max
```

## License

`rstr-max` is distributed under the terms of the [AGPLv3](https://www.gnu.org/licenses/agpl-3.0.html) license.

